@@ -8,23 +8,23 @@ void Survival::loadS3()
     bool push = true;
     while (true)
     {
-        LineInfo const *line = lines.get();
+        LineInfo const *line = lines.get();     // load the lines of S3
 
         if (line == 0)                          // no (more) lines
             break;
 
-        ProbGroup group;
+        ProbGroup group{ SINGLE };
 
         if (not Parser::extract(*line, group))
             push = false;
-        
+
         if (not push)
             continue;                           // continue for syntax-check
                                                 // purposes
 
         if (group.group().nextRange(d_s3))      // add the next range
-        {
-            d_s3.push_back(move(group));
+        {                                       // (0 - 11 thru 71 - *)
+            d_s3.push_back(move(group));        // add the info to d_s3
             continue;
         }
 
